<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_CN">
<context>
    <name>AccessDialog</name>
    <message>
        <location filename="../../../src/accessdialog.cpp" line="51"/>
        <source>Deny Access</source>
        <translation>拒绝</translation>
    </message>
    <message>
        <location filename="../../../src/accessdialog.cpp" line="59"/>
        <source>Grant Access</source>
        <translation>授权</translation>
    </message>
</context>
<context>
    <name>AppChooserDialog</name>
    <message>
        <location filename="../../../src/appchooserdialog.cpp" line="18"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../../../src/appchooserdialog.cpp" line="19"/>
        <source>Confirm</source>
        <translation>确认</translation>
    </message>
</context>
</TS>